; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
[command]
name = "rage"
command = ~D, DF, F, a+b
time = 15

[command]
name = "rage"
command = ~D, DF, F,B,U,U, a+b
time = 1

[command]
name = "striker"
command = ~D, DB, B, a+b
time = 15

[command]
name = "striker"
command = ~D, F, B, U, a, b
time = 1

[command]
name = "rendan"
command = ~D, DF, F, b
time = 15

[command]
name = "rendan"
command = ~D, DF, F, a, a, b
time = 1

[command]
name = "heal"
command = ~D, DF, F, a
time = 15

[command]
name = "heal"
command = ~D, DF, F, a, a, a
time = 1

;-| Special Motions |------------------------------------------------------


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "teleport"
command = a+b
time = 10

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;create scroll menu
[state -1]
type = helper
trigger1 = time = 0 && roundstate = 2 && numhelper(8000) = 0
helpertype = normal
pos = 0,0
stateno = 7010
keyctrl = 0
ownpal = 1
ID = 8000

;strikers
[state -1]
type = changestate
triggerall = numhelper(3000) = 0 && numhelper(3010) = 0 && numhelper(3020) = 0 && numhelper(3040) = 0
triggerall = numhelper(3050) = 0
triggerall = numhelper(8000) = 1
trigger1 = helper(8000), numhelper(1) = 1 || helper(8000), numhelper(2) = 1 || helper(8000), numhelper(3) = 1
trigger1 = command = "striker"
trigger1 = ctrl && statetype != A
trigger1 = power >= 500
value = 3060

;Sakura Rage
[state -1]
type = changestate
triggerall = command = "rage" && var(6) = 0
trigger1 = ctrl && statetype != A
trigger1 = power >= 1000
value = 3000

;Sakura Rendan
[state -1]
type = changestate
triggerall = command = "rendan"
trigger1 = ctrl && statetype != A
trigger1 = power >= 800
value = 1010

;Meditation healing
[state -1]
type = changestate
triggerall = command = "heal" && var(0) = 0
trigger1 = ctrl && statetype != A
trigger1 = power >= 500
value = 1000

;---------------------------------------------------------------------------
;throw weaponry
[state -1]
type = changestate
triggerall = command = "a" || command = "b"
triggerall = var(5) != 0
trigger1 = ctrl && statetype != A
value = 1020

;throw weaponry
[state -1]
type = changestate
triggerall = command = "a" || command = "b"
triggerall = var(5) != 0
trigger1 = ctrl && statetype = A
value = 1021
;---------------------------------------------------------------------------
;sakura rage attack
[state -1]
type = changestate
triggerall = var(6) > 0 && p2dist X< 60 && ctrl
triggerall = statetype != A
trigger1 = command = "a"
trigger2 = command = "b"
value = 3001

;---------------------------------------------------------------------------
;teleport
[State -1]
type = ChangeState
value = 410
triggerall = command = "teleport"
trigger1 = statetype != A
trigger1 = ctrl && power >= 20

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;dash punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 240
triggerall = command = "a" || command = "b"
trigger1 = statetype != A
trigger1 = stateno = 100

;===========================================================================
;launcher
[State -1, Stand Strong Punch]
type = ChangeState
value = 400
triggerall = command = "a" || command = "b"
trigger1 = statetype = C && (command = "holdfwd" || command = "holdback")
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "a"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "a"
trigger1 = statetype != A
trigger1 = stateno = 200 && movecontact
trigger2 = stateno = 230 && movecontact
trigger3 = stateno = 200 && animelemtime(3) >= 0

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 220
triggerall = command = "b"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 && movecontact

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 230
triggerall = command = "b"
trigger1 = statetype != A
trigger1 = stateno = 220 && movecontact
trigger2 = stateno = 220 && animelemtime(3) >= 0

;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 610 && movecontact && prevstateno != 600

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 610
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 && movecontact && prevstateno != 610

